@@ -14,11 +14,8 @@ module Hakyll.Commands
 
 
 --------------------------------------------------------------------------------
-import           Control.Applicative
 import           Control.Concurrent
-import           Control.Monad              (void)
 import           System.Exit                (ExitCode, exitWith)
-import           System.IO.Error            (catchIOError)
 
 --------------------------------------------------------------------------------
 import qualified Hakyll.Check               as Check
@@ -39,6 +36,11 @@ import           Hakyll.Preview.Poll        (watchUpdates)
 import           Hakyll.Preview.Server
 #endif
 
+#ifdef mingw32_HOST_OS
+import           Control.Monad              (void)
+import           System.IO.Error            (catchIOError)
+#endif
+
 
 --------------------------------------------------------------------------------
 -- | Build the site
