@@ -54,7 +54,7 @@
 -- The @for@ macro is used for enumerating 'Context' elements that are
 -- lists, i.e. constructed using the 'listField' function. Assume that
 -- in a context we have an element @listField \"key\" c itms@. Then
--- the snippet 
+-- the snippet
 --
 -- > $for(key)$
 -- >   $x$
@@ -70,21 +70,21 @@
 --
 -- > listField "things" (field "thing" (return . itemBody))
 -- >    (sequence [makeItem "fruits", makeItem "vegetables"])
--- 
+--
 -- and a template
 --
 -- >  I like
 -- >  $for(things)$
--- >    fresh $thing$$sep$, and 
+-- >    fresh $thing$$sep$, and
 -- >  $endfor$
 --
 -- the resulting page would look like
 --
 -- > <p>
 -- >  I like
--- > 
--- >   fresh fruits, and 
--- > 
+-- >
+-- >   fresh fruits, and
+-- >
 -- >   fresh vegetables
 -- > </p>
 --
@@ -118,6 +118,7 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 module Hakyll.Web.Template
     ( Template
+    , templateBodyCompiler
     , templateCompiler
     , applyTemplate
     , loadAndApplyTemplate
@@ -128,9 +129,8 @@ module Hakyll.Web.Template
 
 --------------------------------------------------------------------------------
 import           Control.Monad                (liftM)
-import           Control.Monad.Error          (MonadError (..))
+import           Control.Monad.Except         (MonadError (..))
 import           Data.List                    (intercalate)
-import           Data.Monoid                  (mappend)
 import           Prelude                      hiding (id)
 
 
@@ -143,7 +143,14 @@ import           Hakyll.Web.Template.Internal
 
 
 --------------------------------------------------------------------------------
--- | Read a template.
+-- | Read a template, without metadata header
+templateBodyCompiler :: Compiler (Item Template)
+templateBodyCompiler = cached "Hakyll.Web.Template.templateBodyCompiler" $ do
+    item <- getResourceBody
+    return $ fmap readTemplate item
+
+--------------------------------------------------------------------------------
+-- | Read complete file contents as a template
 templateCompiler :: Compiler (Item Template)
 templateCompiler = cached "Hakyll.Web.Template.templateCompiler" $ do
     item <- getResourceString
